Description Usage Arguments Value
Draw a single sample from the feasible set of species abundance
distributions with s species and n total individuals, uniformly
1 | send_gnome(s, n, ps, ks)
|
s |
the number of species |
n |
the number of individuals |
ps |
the ps table for number of partitions |
ks |
the ks table of max partition sizes |
a vector of length s whose elements sum up to n, in non-
decreasing order
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.